@@ -5,14 +5,12 @@ from ..utils import parse_input_data, parse_output_projection
 __all__ = ['reproject_from_healpix', 'reproject_to_healpix']
 
 
-def reproject_from_healpix(input_data, output_projection, shape_out=None, hdu_in=None, order='bilinear', nested=False, field=0):
+def reproject_from_healpix(input_data, output_projection, shape_out=None,
+                           hdu_in=1, order='bilinear', nested=None,
+                           field=0):
     """
     Reproject data from a HEALPIX projection to a standard projection.
 
-    .. note:: This function uses healpy, which is licensed
-              under the GPLv2, so any package using this funtions has to (for
-              now) abide with the GPLv2 rather than the BSD license.
-
     Parameters
     ----------
     input_data : str or `~astropy.io.fits.TableHDU` or `~astropy.io.fits.BinTableHDU` or tuple
@@ -33,6 +31,8 @@ def reproject_from_healpix(input_data, output_projection, shape_out=None, hdu_in
         shape of the output data should be specified separately.
     hdu_in : int or str, optional
         If ``input_data`` is a FITS file, specifies the HDU to use.
+        (the default HDU for HEALPIX data is 1, unlike with image files where
+        it is generally 0)
     order : int or str, optional
         The order of the interpolation (if ``mode`` is set to
         ``'interpolation'``). This can be either one of the following strings:
@@ -43,7 +43,8 @@ def reproject_from_healpix(input_data, output_projection, shape_out=None, hdu_in
         or an integer. A value of ``0`` indicates nearest neighbor
         interpolation.
     nested : bool, optional
-        The order of the healpix_data, either nested (True) or ring (False)
+        The order of the healpix_data, either nested (True) or ring (False).
+        If a FITS file is passed in, this is determined from the header.
     field : int, optional
         The column to read from the HEALPIX FITS file. If the fits file is a
         partial-sky file, field=0 corresponds to the first column after the
@@ -59,20 +60,24 @@ def reproject_from_healpix(input_data, output_projection, shape_out=None, hdu_in
         indicate valid values.
     """
 
-    array_in, coord_system_in = parse_input_healpix_data(input_data, hdu_in=hdu_in, field=field)
+    array_in, coord_system_in, nested = parse_input_healpix_data(input_data, hdu_in=hdu_in,
+                                                                 field=field, nested=nested)
     wcs_out, shape_out = parse_output_projection(output_projection, shape_out=shape_out)
 
-    return healpix_to_image(array_in, coord_system_in, wcs_out, shape_out, order=order, nested=nested)
+    if nested is None:
+        raise ValueError("Could not determine whether the data follows the "
+                         "'ring' or 'nested' ordering, so you should set "
+                         "nested=True or nested=False explicitly.")
+
+    return healpix_to_image(array_in, coord_system_in, wcs_out, shape_out,
+                            order=order, nested=nested)
 
 
-def reproject_to_healpix(input_data, coord_system_out, hdu_in=None, order='bilinear', nested=False, nside=128):
+def reproject_to_healpix(input_data, coord_system_out, hdu_in=0,
+                         order='bilinear', nested=False, nside=128):
     """
     Reproject data from a standard projection to a HEALPIX projection.
 
-    .. note:: This function uses healpy, which is licensed
-              under the GPLv2, so any package using this funtions has to (for
-              now) abide with the GPLv2 rather than the BSD license.
-
     Parameters
     ----------
     input_data : str or `~astropy.io.fits.HDUList` or `~astropy.io.fits.PrimaryHDU` or `~astropy.io.fits.ImageHDU` or tuple
