@@ -1,5 +1,5 @@
 def get_package_data():
     return {
         _ASTROPY_PACKAGE_NAME_ + '.tests': ['coveragerc', 'data/*'],
-        _ASTROPY_PACKAGE_NAME_ + '.interpolation.tests': ['baseline/*']
+        _ASTROPY_PACKAGE_NAME_ + '.interpolation.tests': ['reference/*']
     }
