@@ -8,7 +8,8 @@ from .core import _reproject_celestial
 __all__ = ['reproject_exact']
 
 
-def reproject_exact(input_data, output_projection, shape_out=None, hdu_in=None, parallel=True):
+def reproject_exact(input_data, output_projection, shape_out=None, hdu_in=0,
+                    parallel=True):
     """
     Reproject data to a new projection using flux-conserving spherical
     polygon intersection (this is the slowest algorithm).
