@@ -1,6 +1,6 @@
 import numpy as np
 
-from astropy.tests.helper import pytest
+import pytest
 from astropy.coordinates import FK5, Galactic, ICRS
 from astropy.io import fits
 from astropy.wcs import WCS
